﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Diagnostics;

namespace ConsoleApplication
{
    class Program
    {
        private Process myProcess = new Process();
        private int elapsedTime;
        private bool eventHandled;

        public static void Main(string[] args)
        {
            ConsoleKeyInfo cki;

            // Verify that an argument has been entered. 
            if (args.Length <= 1)
            {
                Console.WriteLine("Enter a file name and argument.");
                cki = Console.ReadKey();
                return;
            }

            Console.Out.WriteLine("Prgram 'ConsoleApplication' running ...\n");

            // Create the process.
            Program myProcess = new Program();
            myProcess.PrintDoc(args[0], args[1]);
        }

        // Print a file with any known extension. 
        public void PrintDoc(string fileName, string arguments)
        {
            ConsoleKeyInfo cki;

            elapsedTime = 0;
            eventHandled = false;

            try
            {
                // Start a process and raise an event when done.
                myProcess.StartInfo.FileName = fileName;
                myProcess.StartInfo.Arguments = arguments;
                myProcess.StartInfo.CreateNoWindow = true;
                myProcess.EnableRaisingEvents = true;
                myProcess.Exited += new EventHandler(myProcess_Exited);
                myProcess.Start();
            }
            catch (Exception ex)
            {
                Console.WriteLine("An error occurred trying to start process \"{0}\":" + "\n" + ex.Message, fileName);
                cki = Console.ReadKey();
                return;
            }

            // Wait for Exited event, but not more than 30 seconds. 
            const int SLEEP_AMOUNT = 100;
            while (!eventHandled)
            {
                elapsedTime += SLEEP_AMOUNT;
                if (elapsedTime > 30000)
                {
                    break;
                }
                Thread.Sleep(SLEEP_AMOUNT);
            }
            cki = Console.ReadKey();
        }

        // Handle Exited event and display process information. 
        private void myProcess_Exited(object sender, System.EventArgs e)
        {
            ConsoleKeyInfo cki;

            eventHandled = true;
            Console.WriteLine("Exit time:    {0}\r\n" +
                              "Elapsed time: {2}\r\n" +
                              "Exit code:    {1}", myProcess.ExitTime, myProcess.ExitCode, elapsedTime);
        }

    }
}
